@@ -233,7 +233,8 @@ void SessionDialog::openSessions()
                     continue;
                 }
                 win->newTabFromName (files.at (i),
-                                     true, // to save the cursor position
+                                     1, // to save the cursor position
+                                     0, // irrelevant
                                      multiple);
             }
             if (broken == files.count())
